From 06cedcff891bdd5a18a1773081cb20726458660b Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 08:55:13 +0200
Subject: [PATCH 01/14] feat: jupyter-notebook: preinstall Python packages

---
 registry/coder/modules/jupyter-notebook/README.md |  2 +-
 registry/coder/modules/jupyter-notebook/main.tf   | 12 ++++++++++++
 2 files changed, 13 insertions(+), 1 deletion(-)

diff --git a/registry/coder/modules/jupyter-notebook/README.md b/registry/coder/modules/jupyter-notebook/README.md
index 9c0cd5e2..a509df6a 100644
--- a/registry/coder/modules/jupyter-notebook/README.md
+++ b/registry/coder/modules/jupyter-notebook/README.md
@@ -16,7 +16,7 @@ A module that adds Jupyter Notebook in your Coder template.
 module "jupyter-notebook" {
   count    = data.coder_workspace.me.start_count
   source   = "registry.coder.com/coder/jupyter-notebook/coder"
-  version  = "1.1.1"
+  version  = "1.2.0"
   agent_id = coder_agent.example.id
 }
 ```
diff --git a/registry/coder/modules/jupyter-notebook/main.tf b/registry/coder/modules/jupyter-notebook/main.tf
index 61cf25eb..a6aa2188 100644
--- a/registry/coder/modules/jupyter-notebook/main.tf
+++ b/registry/coder/modules/jupyter-notebook/main.tf
@@ -48,6 +48,18 @@ variable "group" {
   default     = null
 }
 
+variable "requirements_path" {
+  type        = string
+  description = "The path to requirements.txt with packages to preinstall"
+  default     = ""
+}
+
+variable "pip_install_packages" {
+  type        = string
+  description = "List of packages to preinstall (example: numpy==1.26.4 pandas matplotlib<4 scikit-learn)"
+  default     = ""
+}
+
 resource "coder_script" "jupyter-notebook" {
   agent_id     = var.agent_id
   display_name = "jupyter-notebook"

From 9b3afc28fd55efc7ab20e69fe63fd36ba4c841ed Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 10:31:43 +0200
Subject: [PATCH 02/14] Modify run.sh

---
 .../coder/modules/jupyter-notebook/main.tf    |  4 +++-
 .../coder/modules/jupyter-notebook/run.sh     | 20 ++++++++++++++++++-
 2 files changed, 22 insertions(+), 2 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/main.tf b/registry/coder/modules/jupyter-notebook/main.tf
index a6aa2188..40c0452b 100644
--- a/registry/coder/modules/jupyter-notebook/main.tf
+++ b/registry/coder/modules/jupyter-notebook/main.tf
@@ -66,7 +66,9 @@ resource "coder_script" "jupyter-notebook" {
   icon         = "/icon/jupyter.svg"
   script = templatefile("${path.module}/run.sh", {
     LOG_PATH : var.log_path,
-    PORT : var.port
+    PORT : var.port,
+    REQUIREMENTS_PATH : var.requirements_path,
+    PIP_INSTALL_PACKAGES : var.pip_install_packages
   })
   run_on_start = true
 }
diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index 0c7a9b85..3a16b0d2 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -14,12 +14,30 @@ if ! command -v jupyter-notebook > /dev/null 2>&1; then
     exit 1
   fi
   # install jupyter notebook
-  pipx install -q notebook
+  pipx install --no-cache-dir -q notebook
   echo "🥳 jupyter-notebook has been installed\n\n"
 else
   echo "🥳 jupyter-notebook is already installed\n\n"
 fi
 
+# Install packages selected with REQUIREMENTS_PATH
+if [ -n "$REQUIREMENTS_PATH" ]; then
+  if [ -f "$REQUIREMENTS_PATH" ]; then
+    echo "📄 Installing packages from $REQUIREMENTS_PATH..."
+    pip install --no-cache-dir -r "$REQUIREMENTS_PATH"
+    echo "🥳 Requirements installed\n\n"
+  else
+    echo "⚠️  REQUIREMENTS_PATH is set to '$REQUIREMENTS_PATH' but the file does not exist!\n\n"
+  fi
+fi
+
+# Install packages selected with PIP_INSTALL_PACKAGES
+if [ -n "$PIP_INSTALL_PACKAGES" ]; then
+  echo "📦 Installing extra pip packages: $PIP_INSTALL_PACKAGES"
+  pip install --no-cache-dir $PIP_INSTALL_PACKAGES
+  echo "🥳 Extra packages installed\n\n"
+fi
+
 echo "👷 Starting jupyter-notebook in background..."
 echo "check logs at ${LOG_PATH}"
 $HOME/.local/bin/jupyter-notebook --NotebookApp.ip='0.0.0.0' --ServerApp.port=${PORT} --no-browser --ServerApp.token='' --ServerApp.password='' > ${LOG_PATH} 2>&1 &

From 43339403714a4f03d8fb7d4b6f80386271e8c0b8 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 10:33:03 +0200
Subject: [PATCH 03/14] Modify run.sh

---
 registry/coder/modules/jupyter-notebook/main.tf | 6 +++---
 registry/coder/modules/jupyter-notebook/run.sh  | 8 ++++----
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/main.tf b/registry/coder/modules/jupyter-notebook/main.tf
index 40c0452b..568e8ca7 100644
--- a/registry/coder/modules/jupyter-notebook/main.tf
+++ b/registry/coder/modules/jupyter-notebook/main.tf
@@ -54,9 +54,9 @@ variable "requirements_path" {
   default     = ""
 }
 
-variable "pip_install_packages" {
+variable "pip_install_extra_packages" {
   type        = string
-  description = "List of packages to preinstall (example: numpy==1.26.4 pandas matplotlib<4 scikit-learn)"
+  description = "List of extra packages to preinstall (example: numpy==1.26.4 pandas matplotlib<4 scikit-learn)"
   default     = ""
 }
 
@@ -68,7 +68,7 @@ resource "coder_script" "jupyter-notebook" {
     LOG_PATH : var.log_path,
     PORT : var.port,
     REQUIREMENTS_PATH : var.requirements_path,
-    PIP_INSTALL_PACKAGES : var.pip_install_packages
+    PIP_INSTALL_EXTRA_PACKAGES : var.pip_install_extra_packages
   })
   run_on_start = true
 }
From 46c4b11ccb344ce2e8eafe0ce4512aef58097861 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 10:36:48 +0200
Subject: [PATCH 04/14] Modify run.sh

---
 registry/coder/modules/jupyter-notebook/run.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index 314a9cee..c1978fa1 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -25,7 +25,7 @@ if [ -n "$REQUIREMENTS_PATH" ]; then
   if [ -f "$REQUIREMENTS_PATH" ]; then
     echo "📄 Installing packages from $REQUIREMENTS_PATH..."
     pip install --no-cache-dir -r "$REQUIREMENTS_PATH"
-    echo "🥳 Requirements installed\n\n"
+    echo "🥳 Packages from $REQUIREMENTS_PATH have been installed\n\n"
   else
     echo "⚠️  REQUIREMENTS_PATH is set to '$REQUIREMENTS_PATH' but the file does not exist!\n\n"
   fi
@@ -33,9 +33,9 @@ fi
 
 # Install packages selected with PIP_INSTALL_EXTRA_PACKAGES
 if [ -n "$PIP_INSTALL_EXTRA_PACKAGES" ]; then
-  echo "📦 Installing extra pip packages: $PIP_INSTALL_EXTRA_PACKAGES"
+  echo "📦 Installing additional packages: $PIP_INSTALL_EXTRA_PACKAGES"
   pip install --no-cache-dir $PIP_INSTALL_EXTRA_PACKAGES
-  echo "🥳 Extra packages installed\n\n"
+  echo "🥳 Additional packages have been installed\n\n"
 fi
 
 echo "👷 Starting jupyter-notebook in background..."

From 04735c9c56421c36bcef8a5c4fe101a672af8171 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 10:51:40 +0200
Subject: [PATCH 05/14] fix

---
 registry/coder/modules/jupyter-notebook/run.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index c1978fa1..3881dd9a 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -24,7 +24,7 @@ fi
 if [ -n "$REQUIREMENTS_PATH" ]; then
   if [ -f "$REQUIREMENTS_PATH" ]; then
     echo "📄 Installing packages from $REQUIREMENTS_PATH..."
-    pip install --no-cache-dir -r "$REQUIREMENTS_PATH"
+    pipx runpip cookiecutter install -r "$REQUIREMENTS_PATH"
     echo "🥳 Packages from $REQUIREMENTS_PATH have been installed\n\n"
   else
     echo "⚠️  REQUIREMENTS_PATH is set to '$REQUIREMENTS_PATH' but the file does not exist!\n\n"
@@ -34,7 +34,7 @@ fi
 # Install packages selected with PIP_INSTALL_EXTRA_PACKAGES
 if [ -n "$PIP_INSTALL_EXTRA_PACKAGES" ]; then
   echo "📦 Installing additional packages: $PIP_INSTALL_EXTRA_PACKAGES"
-  pip install --no-cache-dir $PIP_INSTALL_EXTRA_PACKAGES
+  pipx install $PIP_INSTALL_EXTRA_PACKAGES
   echo "🥳 Additional packages have been installed\n\n"
 fi
 

From 6503beacb51fabe11ff2e0574a44986faf933631 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 10:53:08 +0200
Subject: [PATCH 06/14] fix

---
 registry/coder/modules/jupyter-notebook/run.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index 3881dd9a..c86409a4 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -14,7 +14,7 @@ if ! command -v jupyter-notebook > /dev/null 2>&1; then
     exit 1
   fi
   # install jupyter notebook
-  pipx install --no-cache-dir -q notebook
+  pipx install -q notebook
   echo "🥳 jupyter-notebook has been installed\n\n"
 else
   echo "🥳 jupyter-notebook is already installed\n\n"

From 25903747f67024c5a1e6b3206d3fc55729902c3d Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 10:59:50 +0200
Subject: [PATCH 07/14] debug

---
 registry/coder/modules/jupyter-notebook/run.sh | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index c86409a4..36c8a75e 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -36,6 +36,8 @@ if [ -n "$PIP_INSTALL_EXTRA_PACKAGES" ]; then
   echo "📦 Installing additional packages: $PIP_INSTALL_EXTRA_PACKAGES"
   pipx install $PIP_INSTALL_EXTRA_PACKAGES
   echo "🥳 Additional packages have been installed\n\n"
+else
+  echo "DEBUG: $PIP_INSTALL_EXTRA_PACKAGES\n"
 fi
 
 echo "👷 Starting jupyter-notebook in background..."

From 8b92b29d62df04a321c5d8f17678342333087111 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 11:01:40 +0200
Subject: [PATCH 08/14] debug

---
 registry/coder/modules/jupyter-notebook/run.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index 36c8a75e..9e85c9ec 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -37,7 +37,7 @@ if [ -n "$PIP_INSTALL_EXTRA_PACKAGES" ]; then
   pipx install $PIP_INSTALL_EXTRA_PACKAGES
   echo "🥳 Additional packages have been installed\n\n"
 else
-  echo "DEBUG: $PIP_INSTALL_EXTRA_PACKAGES\n"
+  echo "DEBUG: $PIP_INSTALL_EXTRA_PACKAGES Port: $PORT\n"
 fi
 
 echo "👷 Starting jupyter-notebook in background..."

From 5a837eeba793f08677bffa79f7cca69ed5ddd8d3 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 11:03:38 +0200
Subject: [PATCH 09/14] debug

---
 registry/coder/modules/jupyter-notebook/run.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index 9e85c9ec..dc0eac56 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -37,7 +37,7 @@ if [ -n "$PIP_INSTALL_EXTRA_PACKAGES" ]; then
   pipx install $PIP_INSTALL_EXTRA_PACKAGES
   echo "🥳 Additional packages have been installed\n\n"
 else
-  echo "DEBUG: $PIP_INSTALL_EXTRA_PACKAGES Port: $PORT\n"
+  echo "DEBUG: ${PIP_INSTALL_EXTRA_PACKAGES} Port: ${PORT}\n"
 fi
 
 echo "👷 Starting jupyter-notebook in background..."

From f7ccf8125ac7b4953377ec41c2707b9ef7e19037 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 11:05:30 +0200
Subject: [PATCH 10/14] debug

---
 .../coder/modules/jupyter-notebook/run.sh     | 20 +++++++++----------
 1 file changed, 9 insertions(+), 11 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index dc0eac56..b2a6e5aa 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -21,23 +21,21 @@ else
 fi
 
 # Install packages selected with REQUIREMENTS_PATH
-if [ -n "$REQUIREMENTS_PATH" ]; then
-  if [ -f "$REQUIREMENTS_PATH" ]; then
-    echo "📄 Installing packages from $REQUIREMENTS_PATH..."
-    pipx runpip cookiecutter install -r "$REQUIREMENTS_PATH"
-    echo "🥳 Packages from $REQUIREMENTS_PATH have been installed\n\n"
+if [ -n "${REQUIREMENTS_PATH}" ]; then
+  if [ -f "${REQUIREMENTS_PATH}" ]; then
+    echo "📄 Installing packages from ${REQUIREMENTS_PATH}..."
+    pipx runpip cookiecutter install -r "${REQUIREMENTS_PATH}"
+    echo "🥳 Packages from ${REQUIREMENTS_PATH} have been installed\n\n"
   else
-    echo "⚠️  REQUIREMENTS_PATH is set to '$REQUIREMENTS_PATH' but the file does not exist!\n\n"
+    echo "⚠️  REQUIREMENTS_PATH is set to '${REQUIREMENTS_PATH}' but the file does not exist!\n\n"
   fi
 fi
 
 # Install packages selected with PIP_INSTALL_EXTRA_PACKAGES
-if [ -n "$PIP_INSTALL_EXTRA_PACKAGES" ]; then
-  echo "📦 Installing additional packages: $PIP_INSTALL_EXTRA_PACKAGES"
-  pipx install $PIP_INSTALL_EXTRA_PACKAGES
+if [ -n "${PIP_INSTALL_EXTRA_PACKAGES}" ]; then
+  echo "📦 Installing additional packages: ${PIP_INSTALL_EXTRA_PACKAGES}"
+  pipx install ${PIP_INSTALL_EXTRA_PACKAGES}
   echo "🥳 Additional packages have been installed\n\n"
-else
-  echo "DEBUG: ${PIP_INSTALL_EXTRA_PACKAGES} Port: ${PORT}\n"
 fi
 
 echo "👷 Starting jupyter-notebook in background..."

From 07183cd7cb11e89972f2f698331596ca26ce857d Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 11:12:16 +0200
Subject: [PATCH 11/14] fix

---
 registry/coder/modules/jupyter-notebook/run.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index b2a6e5aa..c4a16aa7 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -24,7 +24,7 @@ fi
 if [ -n "${REQUIREMENTS_PATH}" ]; then
   if [ -f "${REQUIREMENTS_PATH}" ]; then
     echo "📄 Installing packages from ${REQUIREMENTS_PATH}..."
-    pipx runpip cookiecutter install -r "${REQUIREMENTS_PATH}"
+    pipx runpip install -r "${REQUIREMENTS_PATH}"
     echo "🥳 Packages from ${REQUIREMENTS_PATH} have been installed\n\n"
   else
     echo "⚠️  REQUIREMENTS_PATH is set to '${REQUIREMENTS_PATH}' but the file does not exist!\n\n"
@@ -34,7 +34,7 @@ fi
 # Install packages selected with PIP_INSTALL_EXTRA_PACKAGES
 if [ -n "${PIP_INSTALL_EXTRA_PACKAGES}" ]; then
   echo "📦 Installing additional packages: ${PIP_INSTALL_EXTRA_PACKAGES}"
-  pipx install ${PIP_INSTALL_EXTRA_PACKAGES}
+  pipx runpip install ${PIP_INSTALL_EXTRA_PACKAGES}
   echo "🥳 Additional packages have been installed\n\n"
 fi
 

From 30e254761203d9922a5f9f683a1e0c74c3c937a6 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 11:16:45 +0200
Subject: [PATCH 12/14] fix

---
 registry/coder/modules/jupyter-notebook/run.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index c4a16aa7..451444d6 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -24,7 +24,7 @@ fi
 if [ -n "${REQUIREMENTS_PATH}" ]; then
   if [ -f "${REQUIREMENTS_PATH}" ]; then
     echo "📄 Installing packages from ${REQUIREMENTS_PATH}..."
-    pipx runpip install -r "${REQUIREMENTS_PATH}"
+    pipx runpip jupyter-notebook install -r "${REQUIREMENTS_PATH}"
     echo "🥳 Packages from ${REQUIREMENTS_PATH} have been installed\n\n"
   else
     echo "⚠️  REQUIREMENTS_PATH is set to '${REQUIREMENTS_PATH}' but the file does not exist!\n\n"
@@ -34,7 +34,7 @@ fi
 # Install packages selected with PIP_INSTALL_EXTRA_PACKAGES
 if [ -n "${PIP_INSTALL_EXTRA_PACKAGES}" ]; then
   echo "📦 Installing additional packages: ${PIP_INSTALL_EXTRA_PACKAGES}"
-  pipx runpip install ${PIP_INSTALL_EXTRA_PACKAGES}
+  pipx runpip jupyter-notebook install ${PIP_INSTALL_EXTRA_PACKAGES}
   echo "🥳 Additional packages have been installed\n\n"
 fi
 

From bc295f566c12dc0a9c841d5b122c2dd015255373 Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 11:18:48 +0200
Subject: [PATCH 13/14] fix

---
 registry/coder/modules/jupyter-notebook/run.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index 451444d6..c22a7227 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -24,7 +24,7 @@ fi
 if [ -n "${REQUIREMENTS_PATH}" ]; then
   if [ -f "${REQUIREMENTS_PATH}" ]; then
     echo "📄 Installing packages from ${REQUIREMENTS_PATH}..."
-    pipx runpip jupyter-notebook install -r "${REQUIREMENTS_PATH}"
+    pipx runpip notebook install -r "${REQUIREMENTS_PATH}"
     echo "🥳 Packages from ${REQUIREMENTS_PATH} have been installed\n\n"
   else
     echo "⚠️  REQUIREMENTS_PATH is set to '${REQUIREMENTS_PATH}' but the file does not exist!\n\n"
@@ -34,7 +34,7 @@ fi
 # Install packages selected with PIP_INSTALL_EXTRA_PACKAGES
 if [ -n "${PIP_INSTALL_EXTRA_PACKAGES}" ]; then
   echo "📦 Installing additional packages: ${PIP_INSTALL_EXTRA_PACKAGES}"
-  pipx runpip jupyter-notebook install ${PIP_INSTALL_EXTRA_PACKAGES}
+  pipx runpip notebook install ${PIP_INSTALL_EXTRA_PACKAGES}
   echo "🥳 Additional packages have been installed\n\n"
 fi
 

From 1543ef5a57278ebbe545ed36a0e1fdf75af9a92b Mon Sep 17 00:00:00 2001
From: Marcin Tojek <marcin@coder.com>
Date: Wed, 30 Jul 2025 11:24:14 +0200
Subject: [PATCH 14/14] debug

---
 registry/coder/modules/jupyter-notebook/run.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index c22a7227..797d9b41 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -24,7 +24,7 @@ fi
 if [ -n "${REQUIREMENTS_PATH}" ]; then
   if [ -f "${REQUIREMENTS_PATH}" ]; then
     echo "📄 Installing packages from ${REQUIREMENTS_PATH}..."
-    pipx runpip notebook install -r "${REQUIREMENTS_PATH}"
+    pipx -q runpip notebook install -r "${REQUIREMENTS_PATH}"
     echo "🥳 Packages from ${REQUIREMENTS_PATH} have been installed\n\n"
   else
     echo "⚠️  REQUIREMENTS_PATH is set to '${REQUIREMENTS_PATH}' but the file does not exist!\n\n"
@@ -34,7 +34,7 @@ fi
 # Install packages selected with PIP_INSTALL_EXTRA_PACKAGES
 if [ -n "${PIP_INSTALL_EXTRA_PACKAGES}" ]; then
   echo "📦 Installing additional packages: ${PIP_INSTALL_EXTRA_PACKAGES}"
-  pipx runpip notebook install ${PIP_INSTALL_EXTRA_PACKAGES}
+  pipx -q runpip notebook install ${PIP_INSTALL_EXTRA_PACKAGES}
   echo "🥳 Additional packages have been installed\n\n"
 fi
 

diff --git a/registry/coder/modules/jupyter-notebook/run.sh b/registry/coder/modules/jupyter-notebook/run.sh
index 3a16b0d2..314a9cee 100644
--- a/registry/coder/modules/jupyter-notebook/run.sh
+++ b/registry/coder/modules/jupyter-notebook/run.sh
@@ -31,10 +31,10 @@ if [ -n "$REQUIREMENTS_PATH" ]; then
   fi
 fi
 
-# Install packages selected with PIP_INSTALL_PACKAGES
-if [ -n "$PIP_INSTALL_PACKAGES" ]; then
-  echo "📦 Installing extra pip packages: $PIP_INSTALL_PACKAGES"
-  pip install --no-cache-dir $PIP_INSTALL_PACKAGES
+# Install packages selected with PIP_INSTALL_EXTRA_PACKAGES
+if [ -n "$PIP_INSTALL_EXTRA_PACKAGES" ]; then
+  echo "📦 Installing extra pip packages: $PIP_INSTALL_EXTRA_PACKAGES"
+  pip install --no-cache-dir $PIP_INSTALL_EXTRA_PACKAGES
   echo "🥳 Extra packages installed\n\n"
 fi
 
